==> eiffelstudio-16.05.tar: F_code/C11/i1542.c <==
/*
 * Code for class I18N_LOCALE_ID
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "i1542.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {I18N_LOCALE_ID}.make_from_string */
void F1157_9536 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Current);
	RTLR(4,loc3);
	RTLIU(5);
	
	RTEAA("make_from_string", 1156, Current, 3, 1, 15454);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1026, 0x00).id, 1026, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1027_7597(RTCW(tr1), arg1);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '@';
	loc2 = F1025_7535(RTCW(loc1), tw1, ((EIF_INTEGER_32) 1L));
	RTHOOK(3);
	if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
		RTHOOK(4);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
		tr1 = F1027_7683(RTCW(loc1), (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L)), ti4_1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
		RTHOOK(5);
		F1027_7619(RTCW(loc1), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
	}
	RTHOOK(6);
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
	loc2 = F1025_7535(RTCW(loc1), tw1, ((EIF_INTEGER_32) 1L));
	RTHOOK(7);
	if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
		RTHOOK(8);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
		tr1 = F1027_7683(RTCW(loc1), (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L)), ti4_1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
		RTHOOK(9);
		F1027_7619(RTCW(loc1), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
	}
	RTHOOK(10);
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
	loc2 = F1025_7535(RTCW(loc1), tw1, ((EIF_INTEGER_32) 1L));
	RTHOOK(11);
	if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
		RTHOOK(12);
		tr1 = F1027_7683(RTCW(loc1), ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
		RTHOOK(13);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
		tr1 = F1027_7683(RTCW(loc1), (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L)), ti4_1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(14);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '-';
		loc3 = F1022_7490(RTCW(loc1), tw1);
		RTHOOK(15);
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3519[Dtype(loc3)-657])(RTCW(loc3));
		switch (ti4_1) {
			case 1L:
				RTHOOK(16);
				ti4_1 = ((EIF_INTEGER_32) 1L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R3450[Dtype(loc3)-806])(RTCW(loc3), (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				RTHOOK(17);
				tr1 = RTLNSMART(eif_new_type(1026, 0).id);
				F1022_7412(RTCW(tr1));
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
				break;
			case 2L:
				RTHOOK(18);
				ti4_1 = ((EIF_INTEGER_32) 1L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R3450[Dtype(loc3)-806])(RTCW(loc3), (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				RTHOOK(19);
				ti4_1 = ((EIF_INTEGER_32) 2L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R3450[Dtype(loc3)-806])(RTCW(loc3), (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
				break;
			case 3L:
				RTHOOK(20);
				ti4_1 = ((EIF_INTEGER_32) 1L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R3450[Dtype(loc3)-806])(RTCW(loc3), (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				RTHOOK(21);
				ti4_1 = ((EIF_INTEGER_32) 2L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R3450[Dtype(loc3)-806])(RTCW(loc3), (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
				RTHOOK(22);
				ti4_1 = ((EIF_INTEGER_32) 3L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R3450[Dtype(loc3)-806])(RTCW(loc3), (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
				break;
			default:
				RTHOOK(23);
				tr1 = RTLNSMART(eif_new_type(1026, 0).id);
				F1022_7412(RTCW(tr1));
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				RTHOOK(24);
				tr1 = RTLNSMART(eif_new_type(1026, 0).id);
				F1022_7412(RTCW(tr1));
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
				break;
		}
	}
	RTHOOK(25);
	F1157_9546(Current);
	RTHOOK(26);
	RTLE;
	RTEE;
}

/* {I18N_LOCALE_ID}.name */
EIF_REFERENCE F1157_9537 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {I18N_LOCALE_ID}.full_name */
EIF_REFERENCE F1157_9538 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {I18N_LOCALE_ID}.language */
EIF_REFERENCE F1157_9539 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {I18N_LOCALE_ID}.region */
EIF_REFERENCE F1157_9540 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {I18N_LOCALE_ID}.script */
EIF_REFERENCE F1157_9541 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {I18N_LOCALE_ID}.language_id */
EIF_REFERENCE F1157_9542 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("language_id", 1156, Current, 0, 0, 15460);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1155, 0x00).id, 1155, _OBJSIZ_1_0_0_0_0_0_0_0_);
	F1156_9531(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_2_));
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

/* {I18N_LOCALE_ID}.hash_code */
EIF_INTEGER_32 F1157_9543 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("hash_code", 1156, Current, 0, 0, 15461);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F1022_7421(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {I18N_LOCALE_ID}.is_equal */
EIF_BOOLEAN F1157_9544 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_equal", 1156, Current, 0, 1, 15462);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	tb2 = F1025_7547(RTCW(tr1), tr2);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
		tb2 = F1025_7547(RTCW(tr1), tr2);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		Result = F1_10(Current, *(EIF_REFERENCE *)(Current + _REFACS_4_), tr1);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {I18N_LOCALE_ID}.encoding */
EIF_REFERENCE F1157_9545 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


/* {I18N_LOCALE_ID}.set_name */
void F1157_9546 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("set_name", 1156, Current, 0, 0, 15464);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	tb1 = F436_3762(RTCW(tr1));
	if ((EIF_BOOLEAN) !tb1) {
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
		F1027_7651(RTCW(tr1), tw1);
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(Current);
		F1027_7637(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_3_));
		RTHOOK(6);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
		F1027_7651(RTCW(tr1), tw1);
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1027_7637(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_3_));
	}
	RTHOOK(8);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_5_) != NULL)) {
		RTHOOK(9);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
		F1027_7651(RTCW(tr1), tw1);
		RTHOOK(10);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1027_7640(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_5_));
	}
	RTHOOK(11);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_4_) != NULL)) {
		RTHOOK(12);
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '@';
		F1027_7651(RTCW(tr1), tw1);
		RTHOOK(13);
		tr1 = *(EIF_REFERENCE *)(Current);
		F1027_7640(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_4_));
		RTHOOK(14);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '@';
		F1027_7651(RTCW(tr1), tw1);
		RTHOOK(15);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1027_7640(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_4_));
	}
	RTHOOK(16);
	RTLE;
	RTEE;
}

void EIF_Minit542 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C11/i1542.c <==
/*
 * Code for class I18N_LOCALE_ID
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "i1542.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {I18N_LOCALE_ID}.make_from_string */
void F1209_10232 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc3);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(1032, 0x01).id, 1032, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1033_8263(RTCW(loc1), arg1);
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '@';
	loc2 = F1031_8201(RTCW(loc1), tw1, ((EIF_INTEGER_32) 1L));
	if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
		tr1 = F1033_8349(RTCW(loc1), (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L)), ti4_1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
		F1033_8285(RTCW(loc1), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
	}
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
	loc2 = F1031_8201(RTCW(loc1), tw1, ((EIF_INTEGER_32) 1L));
	if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
		tr1 = F1033_8349(RTCW(loc1), (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L)), ti4_1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
		F1033_8285(RTCW(loc1), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
	}
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
	loc2 = F1031_8201(RTCW(loc1), tw1, ((EIF_INTEGER_32) 1L));
	if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
		tr1 = F1033_8349(RTCW(loc1), ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
		tr1 = F1033_8349(RTCW(loc1), (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L)), ti4_1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	} else {
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '-';
		loc3 = F1024_7975(RTCW(loc1), tw1);
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5399[Dtype(RTCW(loc3))-749])(loc3);
		switch (ti4_1) {
			case 1L:
				ti4_1 = ((EIF_INTEGER_32) 1L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5330[Dtype(RTCW(loc3))-826])(loc3, (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				tr1 = RTLNSMART(eif_new_type(1032, 1).id);
				F1024_7897(RTCW(tr1));
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
				break;
			case 2L:
				ti4_1 = ((EIF_INTEGER_32) 1L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5330[Dtype(RTCW(loc3))-826])(loc3, (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				ti4_1 = ((EIF_INTEGER_32) 2L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5330[Dtype(RTCW(loc3))-826])(loc3, (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
				break;
			case 3L:
				ti4_1 = ((EIF_INTEGER_32) 1L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5330[Dtype(RTCW(loc3))-826])(loc3, (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				ti4_1 = ((EIF_INTEGER_32) 2L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5330[Dtype(RTCW(loc3))-826])(loc3, (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
				ti4_1 = ((EIF_INTEGER_32) 3L);
				tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5330[Dtype(RTCW(loc3))-826])(loc3, (EIF_REFERENCE) &ti4_1);
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
				break;
			default:
				tr1 = RTLNSMART(eif_new_type(1032, 1).id);
				F1024_7897(RTCW(tr1));
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				tr1 = RTLNSMART(eif_new_type(1032, 1).id);
				F1024_7897(RTCW(tr1));
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
				break;
		}
	}
	F1209_10242(Current);
	RTLE;
}

/* {I18N_LOCALE_ID}.language_id */
EIF_REFERENCE F1209_10238 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1207, 0x01).id, 1207, _OBJSIZ_1_0_0_0_0_0_0_0_);
	F1208_10227(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_2_));
	RTLE;
	return (EIF_REFERENCE) tr1;
}

/* {I18N_LOCALE_ID}.hash_code */
EIF_INTEGER_32 F1209_10239 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = F1024_7906(RTCW(tr1));
	RTLE;
	return Result;
}

/* {I18N_LOCALE_ID}.is_equal */
EIF_BOOLEAN F1209_10240 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	Result = '\0';
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
	tb2 = F1031_8213(RTCW(tr1), tr2);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
		tb2 = F1031_8213(RTCW(tr1), tr2);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		Result = F1_10(Current, *(EIF_REFERENCE *)(Current + _REFACS_4_), tr1);
	}
	RTLE;
	return Result;
}

/* {I18N_LOCALE_ID}.set_name */
void F1209_10242 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = F1_14(tr1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = F1_14(tr1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	tb1 = F714_6083(RTCW(tr1));
	if ((EIF_BOOLEAN) !tb1) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
		F1033_8317(RTCW(tr1), tw1);
		tr1 = *(EIF_REFERENCE *)(Current);
		F1033_8303(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_3_));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
		F1033_8317(RTCW(tr1), tw1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1033_8303(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_3_));
	}
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_5_) != NULL)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '.';
		F1033_8317(RTCW(tr1), tw1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1033_8306(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_5_));
	}
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_4_) != NULL)) {
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '@';
		F1033_8317(RTCW(tr1), tw1);
		tr1 = *(EIF_REFERENCE *)(Current);
		F1033_8306(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_4_));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '@';
		F1033_8317(RTCW(tr1), tw1);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F1033_8306(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_4_));
	}
	RTLE;
}

void EIF_Minit542 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
